changeset 6303:7acbc95b4b2b

enabled InstanceOfSnippets for general lowering of InstanceOfNodes
author Doug Simon <doug.simon@oracle.com>
date Fri, 31 Aug 2012 22:20:13 +0200
parents 5d7d9a6953bd
children ed73a5639244
files graal/com.oracle.graal.compiler/src/com/oracle/graal/compiler/GraalOptions.java graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/snippets/InstanceOfSnippets.java
diffstat 2 files changed, 8 insertions(+), 7 deletions(-) [+]
line wrap: on
line diff
--- a/graal/com.oracle.graal.compiler/src/com/oracle/graal/compiler/GraalOptions.java	Fri Aug 31 17:57:30 2012 +0200
+++ b/graal/com.oracle.graal.compiler/src/com/oracle/graal/compiler/GraalOptions.java	Fri Aug 31 22:20:13 2012 +0200
@@ -271,7 +271,7 @@
      * Only instructions in methods whose fully qualified name contains this option will be HIR lowered.
      */
     public static String HIRLowerCheckcast = "";
-    public static String HIRLowerInstanceOf = "InstanceOfTest";
+    public static String HIRLowerInstanceOf = "";
     public static String HIRLowerNewInstance = "";
     public static String HIRLowerNewArray = "";
 
--- a/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/snippets/InstanceOfSnippets.java	Fri Aug 31 17:57:30 2012 +0200
+++ b/graal/com.oracle.graal.hotspot/src/com/oracle/graal/hotspot/snippets/InstanceOfSnippets.java	Fri Aug 31 22:20:13 2012 +0200
@@ -34,6 +34,7 @@
 import com.oracle.graal.hotspot.*;
 import com.oracle.graal.hotspot.meta.*;
 import com.oracle.graal.nodes.*;
+import com.oracle.graal.nodes.calc.*;
 import com.oracle.graal.nodes.extended.*;
 import com.oracle.graal.nodes.java.*;
 import com.oracle.graal.nodes.spi.*;
@@ -59,7 +60,7 @@
 public class InstanceOfSnippets implements SnippetsInterface {
 
     /**
      * A test against a final type with the result being {@linkplain MaterializeNode materialized}.
      */
     @Snippet
     public static Object materializeExact(
@@ -105,7 +106,7 @@
     }
 
     /**
      * A test against a primary type with the result being {@linkplain MaterializeNode materialized}.
      */
     @Snippet
     public static Object materializePrimary(
@@ -154,7 +155,7 @@
     }
 
     /**
      * A test against a restricted secondary type type with the result being {@linkplain MaterializeNode materialized}.
      */
     @Snippet
     public static Object materializeSecondary(
@@ -218,7 +219,7 @@
     }
 
     /**
      * A test against an unknown (at compile time) type with the result being {@linkplain MaterializeNode materialized}.
      */
     @Snippet
     public static Object materializeUnknown(
@@ -435,9 +436,9 @@
                     template.instantiate(runtime, duplicate, ifNode, arguments);
                     assert ifNode.isDeleted();
 
-                } else if (usage instanceof MaterializeNode) {
+                } else if (usage instanceof ConditionalNode) {
 
-                    MaterializeNode materialize = (MaterializeNode) usage;
+                    ConditionalNode materialize = (ConditionalNode) usage;
                     materialize.replaceAtUsages(duplicate);
                     ValueNode falseValue = materialize.falseValue();
                     ValueNode trueValue = materialize.trueValue();
@@ -59,7 +60,7 @@
 
     /**
-     * A test against a final type with the result being {@linkplain MaterializeNode materialized}.
+     * A test against a final type with the result being {@linkplain ConditionalNode materialized}.
      */
     @Snippet
@@ -105,7 +106,7 @@
 
     /**
-     * A test against a primary type with the result being {@linkplain MaterializeNode materialized}.
+     * A test against a primary type with the result being {@linkplain ConditionalNode materialized}.
      */
     @Snippet
@@ -154,7 +155,7 @@
 
     /**
-     * A test against a restricted secondary type type with the result being {@linkplain MaterializeNode materialized}.
+     * A test against a restricted secondary type type with the result being {@linkplain ConditionalNode materialized}.
      */
     @Snippet
@@ -218,7 +219,7 @@
 
     /**
-     * A test against an unknown (at compile time) type with the result being {@linkplain MaterializeNode materialized}.
+     * A test against an unknown (at compile time) type with the result being {@linkplain ConditionalNode materialized}.
      */
     @Snippet